import React, { useState, useEffect } from 'react';
import { Search, ExternalLink, ChevronDown, Plus, Sun, Moon } from 'lucide-react';
import { pageview, trackToolClick, trackSearch, trackThemeChange } from './utils/analytics';

type Tool = {
  name: string;
  description: string;
  link1: string;
  fees: string;
};

type Category = {
  title: string;
  tools: Tool[];
};

function App() {
  const [searchTerm, setSearchTerm] = useState('');
  const [selectedCategory, setSelectedCategory] = useState('all');
  const [activeDropdown, setActiveDropdown] = useState<string | null>(null);
  const [showSubmitForm, setShowSubmitForm] = useState(false);
  const [isDarkMode, setIsDarkMode] = useState(() => {
    const savedTheme = localStorage.getItem('theme');
    return savedTheme === 'dark' || savedTheme === null || (!savedTheme && window.matchMedia('(prefers-color-scheme: dark)').matches);
  });

  useEffect(() => {
    if (isDarkMode) {
      document.documentElement.classList.add('dark');
      localStorage.setItem('theme', 'dark');
    } else {
      document.documentElement.classList.remove('dark');
      localStorage.setItem('theme', 'light');
    }
  }, [isDarkMode]);

  // 跟踪主题变化
  useEffect(() => {
    trackThemeChange(isDarkMode);
  }, [isDarkMode]);

  const webCategories: Category[] = [
    {
      title: "AI Chat Assistant",
      tools: [
        {
          name: "ChatGPT",
          description: "OpenAI's chatgpt",
          link1: "https://chat.openai.com",
          fees: "Free/Paid"
        },
        {
          name: "DeepSeek",
          description: "DeepSeek's AI assistant.",
          link1: "https://chat.deepseek.com/",
          fees: "Free/Paid"
        },
        {
          name: "Claude",
          description: "Anthropic's AI assistant",
          link1: "https://claude.ai/",
          fees: "Free/Paid"
        },
        {
          name: "Gemini",
          description: "Google's conversational, AI chat service. Google's latest LLM, including Gemini Nono, Gemini Pro and Gemini Ultra. Gemini Pro is open for api and sdk use. Gemini is built from the ground up for multimodality — reasoning seamlessly across text, images, video, audio, and code",
          link1: "https://gemini.google.com/",
          fees: "Free"
        },
        {
          name: "Grok",
          description: "xAI's AI assistant",
          link1: "https://x.com/i/grok",
          fees: "Free"
        },
        {
          name: "Microsoft Copilot",
          description: "Microsoft's AI assistant.",
          link1: "https://copilot.microsoft.com/",
          fees: "Free"
        },
        {
          name: "Le Chat",
          description: "Mistral.ai's conversational, AI chat service",
          link1: "https://chat.mistral.ai/chat",
          fees: "Free"
        },
        {
          name: "qwen",
          description: "Alibaba's AI assistant. Includes QwQ-32B, Qwen2.5-Max, Qwen2.5-Plus, Qwen2.5-VL-72B-Instruct and other Qwen LLMs",
          link1: "https://chat.qwen.ai/",
          fees: "Free"
        }
      ]
    },
    {
      title: "AI Search engine",
      tools: [
        {
          name: "Perplexity.ai",
          description: "AI-driven conversational search engine.",
          link1: "https://www.perplexity.ai",
          fees: "Free"
        },
        {
          name: "You.com",
          description: "A search engine in conversation mode",
          link1: "https://you.com",
          fees: "Free"
        }
      ]
    },
    {
      title: "LLM Leaderboard",
      tools: [
        {
          name: "LMSYS Chatbot Arena Leaderboard",
          description: "LMSYS Chatbot Arena is a crowdsourced open platform for LLM evals. Collected over 1,000,000 human pairwise comparisons to rank LLMs with the Bradley-Terry model and display the model ratings in Elo-scale.",
          link1: "https://chat.lmsys.org/",
          fees: "Free"
        },
        {
          name: "Artificial Analysis",
          description: "Artificial Analysis is a platform that provides AI model and service provider comparisons and benchmarks to help users make informed decisions when choosing AI models and service providers. The platform provides comparative data on a wide range of popular AI models, including OpenAI's GPT-4, Meta's Llama 3, and Anthropic's Claude series, covering performance metrics such as response time, latency, and cost.",
          link1: "https://artificialanalysis.ai/",
          fees: "Free"
        }
      ]
    },
    {
      title: "GPT LLMs Applications",
      tools: [
        {
          name: "Poe",
          description: "AI product built by Quora. Can use ChatGPT, Sage, Dragonfly, Claude bots for free. All you need is an email address to register. GPT-4 can be used once a day for free",
          link1: "https://poe.com/",
          fees: "Free/Paid"
        },
        {
          name: "Google AI Studio",
          description: "Google AI Studio is a free, web-based developer tool that enables you to quickly develop prompts and then get an API key to use in your app development",
          link1: "https://aistudio.google.com/",
          fees: "Free"
        },
        {
          name: "NotebookLM",
          description: "AI Research Assistant developed by Google. Upload PDFs, websites, YouTube videos, audio files, Google Docs, or Google Slides, and NotebookLM will summarize them and make interesting connections between topics. Audio Overview feature can turn your sources into engaging 'Deep Dive' discussions with one click.",
          link1: "https://notebooklm.google.com/",
          fees: "Free"
        },
        {
          name: "Learn about",
          description: "AI learning Assistant developed by Google. Grasp new topics and deepen your understanding with a conversational learning companion that adapts to your unique curiosity and learning goals.",
          link1: "https://learning.google.com/experiments/learn-about",
          fees: "Free"
        },
        {
          name: "Monica",
          description: "AI assistant that provides help with a variety of tasks such as searching, reading, writing, translating, drawing, and more. Standalone apps and browser plug-ins available",
          link1: "https://monica.im",
          fees: "Free/Paid"
        },
        {
          name: "together.ai chat",
          description: "Similar to HuggingChat, with the option of different open source models, support for DeepSeek R1, LLaMA, QWen, Flux Schnell. 60 free messages per day.",
          link1: "https://chat.together.ai/",
          fees: "Free/Paid"
        },
        {
          name: "ChatGPT Sidebar",
          description: "ChatGPT Sidebar is an artificial intelligence assistant you can use while browsing any website.",
          link1: "https://chrome.google.com/webstore/detail/chatgpt-sidebar-support-g/difoiogjjojoaoomphldepapgpbgkhkb",
          fees: "Free"
        },
        {
          name: "AIPRM for ChatGPT",
          description: "Browser plug-in, providing a series of selected ChatGPT instruction templates, and even creating your own, and adjusting AI tone and writing style",
          link1: "https://chrome.google.com/webstore/detail/aiprm-for-chatgpt/ojnbohmppadfgpejeebfnmnknjdlckgj",
          fees: "Free"
        },
        {
          name: "MindMac",
          description: "Feature-rich & privacy-first native ChatGPT app for macOS to use OpenAI, Azure OpenAI, Anthropic Claude, OpenRouter all in one place, designed for maximum productivity. Currently available in 15 languages.",
          link1: "https://mindmac.app/",
          fees: "Free/Paid"
        }
      ]
    },
    {
      title: "Programming Development",
      tools: [
        {
          name: "GitHub Copilot",
          description: "A code writing assistant developed by GitHub and OpenAI",
          link1: "https://github.com/features/copilot",
          fees: "Paid"
        },
        {
          name: "Cursor",
          description: "A collaborative code editor using GPT",
          link1: "https://www.cursor.so",
          fees: "Paid/Free Trial"
        },
        {
          name: "Trae",
          description: "Trae is your helpful coding partner. It offers features like AI Q&A, code auto-completion, and agent-based AI programming capabilities.",
          link1: "https://www.trae.ai/",
          fees: "Free"
        },
        {
          name: "MarsCode",
          description: "Built-in AI programming assistant with capabilities like code completion, explanation, and debugging for faster development.",
          link1: "https://www.marscode.com/",
          fees: "Free"
        },
        {
          name: "Amazon CodeWhisperer",
          description: "A code writing assistant developed by Amazon",
          link1: "https://aws.amazon.com/cn/codewhisperer",
          fees: "Free for Individual Use"
        },
        {
          name: "Codeium",
          description: "Powerful in-IDE AI coding assistant",
          link1: "https://codeium.com/",
          fees: "Free/Paid"
        },
        {
          name: "Fitten Code",
          description: "Fitten Code is an AI programming assistant driven by Fitten LLM models, which can automatically generate code, improve development efficiency, help you debug, and save your time. It can also chat with you and solve your programming problems. Free and supports over 80 languages: Python, C++,JavaScript, TypeScript, Java, etc. Fitten Code supports Visual Studio Code and JetBrains series IDEs, including IntelliJ IDEA, PyCharm, WebStorm, etc.",
          link1: "https://code.fittentech.com/en?lang=en",
          fees: "Free"
        },
        {
          name: "Mistral/Codestral",
          description: "Empowering developers and democratising coding with Mistral AI.",
          link1: "https://chat.mistral.ai/chat",
          fees: "Free"
        }
      ]
    },
    {
      title: "AI Image Creation",
      tools: [
        {
          name: "Midjourney",
          description: "Enter text or pictures to create pictures",
          link1: "https://www.midjourney.com",
          fees: "Free/Paid"
        },
        {
          name: "Photoshop AI",
          description: "Adobe Photoshop generative-fill",
          link1: "https://www.adobe.com/products/photoshop/generative-fill.html",
          fees: "Paid"
        },
        {
          name: "civitai",
          description: "civitai.com is a website platform for sharing AI image creation model resources, with a large number of models, has become the main model exchange place in the SD open source community",
          link1: "https://civitai.com/",
          fees: "Free"
        },
        {
          name: "clipdrop",
          description: "clipdrop by stability.ai. Has many AI image processing tools, such as stable diffusion XL, uncrop, reimage XL, stable doodle.",
          link1: "https://clipdrop.co/",
          fees: "Free/Paid"
        },
        {
          name: "firefly",
          description: "Adobe's AI image processing web site",
          link1: "https://firefly.adobe.com/",
          fees: "Free/Paid"
        },
        {
          name: "ideogram.ai",
          description: "Enter text to create pictures. A product developed by a company founded by many ex-Googlers",
          link1: "https://ideogram.ai/",
          fees: "Free/Paid"
        },
        {
          name: "Nero AI",
          description: "AI picture upscale, AI repair scratches, AI picture coloring, AI picture noise removal, AI one-click to change the background, AI magical erasing pen, AI portrait.",
          link1: "https://ai.nero.com/",
          fees: "Paid/Trial"
        },
        {
          name: "Skybox AI",
          description: "Generate 360-degree panoramic images using text prompts",
          link1: "https://skybox.blockadelabs.com/",
          fees: "Free/Paid"
        },
        {
          name: "remove.bg",
          description: "Remove Image Background",
          link1: "https://www.remove.bg/",
          fees: "Free/Paid"
        },
        {
          name: "Seede AI",
          description: "Helps you create a poster in 1 min",
          link1: "https://seede.ai/",
          fees: "Free/Paid"
        }
      ]
    },
    {
      title: "Video Creation",
      tools: [
        {
          name: "Sora",
          description: "Sora is an AI model published by OpenAI that can create realistic and imaginative scenes from text instructions.",
          link1: "https://openai.com/sora",
          fees: "Paid"
        },
        {
          name: "KLING AI",
          description: "AI Video Creation Tool by kuaishou.",
          link1: "https://klingai.com/",
          fees: "Free/Paid"
        },
        {
          name: "hailuoai",
          description: "AI Video Creation Tool by Minimax",
          link1: "https://hailuoai.com/video",
          fees: "Free/Paid"
        },
        {
          name: "Dream Machine",
          description: "By Luma AI. Dream Machine is an AI model that makes high quality, realistic videos fast from text and images.",
          link1: "https://lumalabs.ai/dream-machine",
          fees: "Free/Paid"
        },
        {
          name: "capcut",
          description: "Subtitle-generated speech, speech recognition, and very convenient and powerful video editing",
          link1: "https://www.capcut.com/",
          fees: "Free/Paid"
        },
        {
          name: "Runway",
          description: "Gen-2: Text/Image to video. Gen-1: Video to video.",
          link1: "https://runwayml.com/",
          fees: "Paid/Free trial"
        },
        {
          name: "Pika",
          description: "Text/Image to video",
          link1: "https://pika.art/home",
          fees: "Paid/Free trial"
        },
        {
          name: "Fliki",
          description: "A website that converts text into audio and video",
          link1: "https://fliki.ai",
          fees: "Free/Paid"
        },
        {
          name: "d-id",
          description: "Generate digital human dubbing video based on text",
          link1: "https://studio.d-id.com",
          fees: "Paid/Free trial"
        },
        {
          name: "HeyGen",
          description: "Generate digital human dubbing video based on text",
          link1: "https://app.heygen.com/",
          fees: "Paid/Free trial"
        },
        {
          name: "vivago.ai/video",
          description: "Text to Video; Image to Video; 4K enhance",
          link1: "https://vivago.ai/video",
          fees: "Free"
        }
      ]
    },
    {
      title: "AI Cloud Platform",
      tools: [
        {
          name: "together.ai",
          description: "The AI Acceleration Cloud. Train, fine-tune-and run inference on AI models blazing fast, at low cost, and at production scale.",
          link1: "https://www.together.ai/",
          fees: "Free/Paid"
        }
      ]
    },
    {
      title: "Writing",
      tools: [
        {
          name: "Notion AI",
          description: "AI-assisted note-taking software",
          link1: "https://www.notion.so",
          fees: "Free Trials/Paid"
        },
        {
          name: "Deep L Write",
          description: "English and German writing tools to fix writing errors and rewrite sentences promptly.",
          link1: "https://www.deepl.com/write",
          fees: "Free/Paid"
        },
        {
          name: "grammarly",
          description: "Edit and correct your grammar, spelling, punctuation, and more with your personal writing assistant, grammar checker, and editor.",
          link1: "https://app.grammarly.com/",
          fees: "Free/Paid"
        },
        {
          name: "TextCraft",
          description: "Add-in for Microsoft Word that seamlessly integrates essential AI tools, including text generation, proofreading, and more, directly into the user interface.",
          link1: "https://github.com/suncloudsmoon/TextCraft",
          fees: "Free"
        }
      ]
    },
    {
      title: "Translation",
      tools: [
        {
          name: "Deep L",
          description: "Accurate and instant translation tool, currently supporting 31 languages",
          link1: "https://www.deepl.com/translator",
          fees: "Free/Paid"
        }
      ]
    },
    {
      title: "Text To Speech",
      tools: [
        {
          name: "Azure Text to speech",
          description: "The best and most realistic voice tools currently available",
          link1: "https://speech.microsoft.com/portal/voicegallery",
          fees: "Free/Paid"
        },
        {
          name: "Hailuo AI Text to Speech",
          description: "Offer over 300 voices in 17 languages and multiple accents, covering a wide range of styles and age groups to provide the voice effects you need.",
          link1: "https://www.hailuo.ai/audio",
          fees: "Free Trials/Paid"
        },
        {
          name: "elevenlabs",
          description: "Intelligent AI Text to Speech",
          link1: "https://elevenlabs.io/",
          fees: "Free/Paid"
        }
      ]
    },
    {
      title: "Music Recognition",
      tools: [
        {
          name: "shazam",
          description: "Download the shazaom app for music recognition, which is pretty fast",
          link1: "https://www.shazam.com/",
          fees: "Free"
        }
      ]
    },
    {
      title: "Voice Processing",
      tools: [
        {
          name: "vocalremover",
          description: "Extract vocal and music",
          link1: "https://vocalremover.org/",
          fees: "Free"
        },
        {
          name: "lala.ai",
          description: "Extract vocal, accompaniment and various instruments from any audio and video",
          link1: "https://www.lalal.ai/",
          fees: "Free/Paid"
        }
      ]
    },
    {
      title: "AI generated music or sound effects",
      tools: [
        {
          name: "suno.ai",
          description: "The AI music creation tool Suno can generate custom songs based on text prompts in mere second",
          link1: "https://www.suno.ai/",
          fees: "Free/Paid"
        },
        {
          name: "udio",
          description: "Create music from simple text prompts by specifying topics, genres, and other descriptors which are then transformed into professional quality tracks.",
          link1: "https://www.udio.com/",
          fees: "Free/Paid"
        },
        {
          name: "elevenlabs/sound-effects",
          description: "Imagine a sound and bring it to life, or explore a selection of the best sound effects generated by the community.",
          link1: "https://elevenlabs.io/app/sound-effects",
          fees: "Free"
        },
        {
          name: "Stable Audio",
          description: "AI music and sound effect generation application by stability.ai",
          link1: "https://www.stableaudio.com/",
          fees: "Free/Paid"
        },
        {
          name: "OptimizerAI",
          description: "Sound effect generation",
          link1: "https://www.optimizerai.xyz/",
          fees: "Free/Paid"
        },
        {
          name: "SFX Engine",
          description: "AI Sound effect generation",
          link1: "https://sfxengine.com/",
          fees: "Free/Paid"
        }
      ]
    },
    {
      title: "Video Content Summary",
      tools: [
        {
          name: "ChatGPT for YouTube",
          description: "Chrome plugin, quickly summarize Youtube video content, need to log in chatgpt account or apikey",
          link1: "https://chatgpt4youtube.com/",
          fees: "Free"
        },
        {
          name: "Chat Youtube",
          description: "Give a Youtube link, it will give a summary, and you can ask it questions about the content of the video",
          link1: "https://chatyoutube.com",
          fees: "Free"
        }
      ]
    },
    {
      title: "Academic research",
      tools: [
        {
          name: "alphaxiv",
          description: "An open academic discussion community based on the arXiv platform that allows users to comment line-by-line, ask questions, and interact in real-time by replacing the paper's linking domain (arxiv.org for alphaxiv.org) directly on the paper's page. And provides AI features such as Ask AI and AI-generated article blogs",
          link1: "https://www.alphaxiv.org/",
          fees: "Free"
        }
      ]
    }
  ];

  // 提取所有类别标题用于导航
  const categories = webCategories.map(cat => cat.title);

  const filteredCategories = webCategories.map(category => ({
    ...category,
    tools: category.tools.filter(tool => 
      tool.name.toLowerCase().includes(searchTerm.toLowerCase()) ||
      tool.description.toLowerCase().includes(searchTerm.toLowerCase())
    )
  })).filter(category => category.tools.length > 0);

  // 添加结构化数据
  const structuredData = {
    "@context": "https://schema.org",
    "@type": "WebSite",
    "name": "Your AI Tools",
    "description": "A comprehensive directory of AI tools for various purposes",
    "url": "https://youraitools.com",
    "potentialAction": {
      "@type": "SearchAction",
      "target": "https://youraitools.com/search?q={search_term_string}",
      "query-input": "required name=search_term_string"
    }
  };

  // 跟踪搜索
  const handleSearch = (e: React.FormEvent) => {
    e.preventDefault();
    if (searchTerm.trim()) {
      trackSearch(searchTerm);
      // ... existing search logic ...
    }
  };

  // 跟踪工具点击
  const handleToolClick = (tool: Tool) => {
    trackToolClick(tool.name, tool.fees);
    window.open(tool.link1, '_blank');
  };

  // 跟踪页面访问
  useEffect(() => {
    pageview(window.location.pathname);
  }, []);

  return (
    <>
      <script
        type="application/ld+json"
        dangerouslySetInnerHTML={{ __html: JSON.stringify(structuredData) }}
      />
      <div className="min-h-screen bg-gradient-to-br from-indigo-50 via-white to-purple-50 dark:from-gray-900 dark:via-gray-800 dark:to-gray-900 transition-colors duration-200">
        {/* Header */}
        <header className="bg-white/80 dark:bg-gray-800/80 backdrop-blur-sm shadow-sm sticky top-0 z-10" role="banner">
          <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8 py-4">
            <div className="flex flex-col items-center justify-between gap-4">
              <div className="flex items-center justify-between w-full">
                <h1 className="text-4xl font-bold bg-gradient-to-r from-indigo-600 to-purple-600 dark:from-indigo-400 dark:to-purple-400 bg-clip-text text-transparent">
                  <a href="/" aria-label="Your AI Tools Home">Your AI Tools</a>
                </h1>
                <button
                  onClick={() => setIsDarkMode(!isDarkMode)}
                  className="p-2 rounded-lg text-gray-600 dark:text-gray-300 hover:bg-gray-100 dark:hover:bg-gray-700 transition-colors"
                  aria-label={isDarkMode ? "Switch to light mode" : "Switch to dark mode"}
                >
                  {isDarkMode ? <Sun size={24} /> : <Moon size={24} />}
                </button>
              </div>
              
              {/* Navigation Bar */}
              <nav className="w-full border-t border-gray-100 dark:border-gray-700 pt-4" role="navigation" aria-label="Main navigation">
                <div className="flex flex-wrap justify-center gap-4">
                  <button
                    onClick={() => setSelectedCategory('all')}
                    className={`px-4 py-2 rounded-lg text-sm font-medium transition-colors ${
                      selectedCategory === 'all'
                        ? 'bg-indigo-100 dark:bg-indigo-900 text-indigo-700 dark:text-indigo-300'
                        : 'text-gray-600 dark:text-gray-300 hover:bg-gray-100 dark:hover:bg-gray-700'
                    }`}
                  >
                    All Tools
                  </button>
                  <div className="relative">
                    <button
                      onClick={() => setActiveDropdown(activeDropdown === 'categories' ? null : 'categories')}
                      className={`px-4 py-2 rounded-lg text-sm font-medium transition-colors flex items-center gap-1 ${
                        activeDropdown === 'categories'
                          ? 'bg-indigo-100 dark:bg-indigo-900 text-indigo-700 dark:text-indigo-300'
                          : 'text-gray-600 dark:text-gray-300 hover:bg-gray-100 dark:hover:bg-gray-700'
                      }`}
                    >
                      Categories
                      <ChevronDown size={16} className={`transition-transform ${activeDropdown === 'categories' ? 'rotate-180' : ''}`} />
                    </button>
                    {activeDropdown === 'categories' && (
                      <div className="absolute top-full left-0 mt-1 w-48 bg-white dark:bg-gray-800 rounded-lg shadow-lg py-2 z-20">
                        {categories.map((category, index) => (
                          <button
                            key={index}
                            onClick={() => {
                              setSelectedCategory(category);
                              setActiveDropdown(null);
                            }}
                            className="w-full text-left px-4 py-2 text-sm text-gray-700 dark:text-gray-300 hover:bg-indigo-50 dark:hover:bg-indigo-900/50 hover:text-indigo-700 dark:hover:text-indigo-300 transition-colors"
                          >
                            {category}
                          </button>
                        ))}
                      </div>
                    )}
                  </div>
                  <button
                    onClick={() => setShowSubmitForm(true)}
                    className="px-4 py-2 rounded-lg text-sm font-medium bg-indigo-600 text-white hover:bg-indigo-700 transition-colors flex items-center gap-2"
                  >
                    <Plus size={16} />
                    Submit Tool
                  </button>
                </div>
              </nav>

              {/* Search Bar */}
              <div className="relative w-full md:w-96" role="search">
                <Search className="absolute left-3 top-1/2 transform -translate-y-1/2 text-gray-400 dark:text-gray-500" size={20} aria-hidden="true" />
                <input
                  type="text"
                  placeholder="Search AI tools..."
                  className="w-full pl-10 pr-4 py-3 border border-gray-200 dark:border-gray-700 rounded-xl focus:outline-none focus:ring-2 focus:ring-indigo-500 focus:border-transparent shadow-sm transition-all duration-200 bg-white dark:bg-gray-800 text-gray-900 dark:text-white placeholder-gray-500 dark:placeholder-gray-400"
                  value={searchTerm}
                  onChange={(e) => setSearchTerm(e.target.value)}
                  aria-label="Search AI tools"
                />
              </div>
            </div>
          </div>
        </header>

        {/* Submit Tool Modal */}
        {showSubmitForm && (
          <div className="fixed inset-0 bg-black bg-opacity-50 flex items-center justify-center z-50">
            <div className="bg-white dark:bg-gray-800 rounded-2xl p-8 max-w-2xl w-full mx-4">
              <div className="flex justify-between items-center mb-6">
                <h2 className="text-2xl font-bold text-gray-900 dark:text-white">Submit a New Tool</h2>
                <button
                  onClick={() => setShowSubmitForm(false)}
                  className="text-gray-400 hover:text-gray-600 dark:hover:text-gray-300"
                >
                  <svg className="w-6 h-6" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                    <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M6 18L18 6M6 6l12 12" />
                  </svg>
                </button>
              </div>
              <div className="space-y-6">
                <div>
                  <h3 className="text-lg font-semibold text-gray-900 dark:text-white mb-2">How to Submit</h3>
                  <p className="text-gray-600 dark:text-gray-300 mb-4">
                    To submit a new AI tool, please send an email to{' '}
                    <a href="mailto:xh896@me.com" className="text-indigo-600 hover:text-indigo-700 dark:text-indigo-400 dark:hover:text-indigo-300">
                      xh896@me.com
                    </a>
                    {' '}with the following information:
                  </p>
                  <div className="bg-gray-50 dark:bg-gray-700/50 p-6 rounded-lg space-y-4">
                    <div>
                      <h4 className="font-medium text-gray-900 dark:text-white mb-1">Required Information:</h4>
                      <ul className="list-disc list-inside text-gray-600 dark:text-gray-300 space-y-2">
                        <li>Tool Name</li>
                        <li>Tool Description (brief and clear)</li>
                        <li>Tool Website URL</li>
                        <li>Pricing Model (Free/Paid/Free Trial)</li>
                        <li>Category (choose from existing categories)</li>
                      </ul>
                    </div>
                    <div>
                      <h4 className="font-medium text-gray-900 dark:text-white mb-1">Example:</h4>
                      <div className="text-gray-600 dark:text-gray-300 space-y-1">
                        <p>Tool Name: Example AI Tool</p>
                        <p>Description: A powerful AI tool that helps users create amazing content</p>
                        <p>Website: https://example.com</p>
                        <p>Pricing: Free/Paid</p>
                        <p>Category: AI Chat Assistant</p>
                      </div>
                    </div>
                  </div>
                </div>
                <div>
                  <h3 className="text-lg font-semibold text-gray-900 dark:text-white mb-2">Guidelines</h3>
                  <ul className="list-disc list-inside text-gray-600 dark:text-gray-300 space-y-2">
                    <li>Please provide accurate and up-to-date information</li>
                    <li>Include a clear and concise description</li>
                    <li>Make sure the tool link is working</li>
                    <li>Specify the correct pricing model</li>
                    <li>Choose an appropriate category from the existing list</li>
                    <li>We will review your submission and add it to our collection if approved</li>
                  </ul>
                </div>
              </div>
            </div>
          </div>
        )}

        {/* Main Content */}
        <main className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8 py-8" role="main">
          <div className="grid gap-8">
            {filteredCategories
              .filter(category => selectedCategory === 'all' || category.title === selectedCategory)
              .map((category, index) => (
              <section key={index} className="bg-white dark:bg-gray-800 rounded-2xl shadow-lg overflow-hidden hover:shadow-xl transition-shadow duration-300" itemScope itemType="https://schema.org/ItemList">
                <h2 className="text-2xl font-bold text-gray-800 dark:text-white p-6 bg-gradient-to-r from-indigo-50 to-purple-50 dark:from-gray-700 dark:to-gray-600 border-b border-gray-100 dark:border-gray-700" itemProp="name">{category.title}</h2>
                <div className="divide-y divide-gray-100 dark:divide-gray-700">
                  {category.tools.map((tool, toolIndex) => (
                    <article key={toolIndex} className="p-6 hover:bg-gradient-to-r hover:from-indigo-50/50 hover:to-purple-50/50 dark:hover:from-gray-700/50 dark:hover:to-gray-600/50 transition-all duration-200" itemScope itemType="https://schema.org/SoftwareApplication">
                      <div className="flex items-start justify-between gap-4">
                        <div className="flex-1">
                          <h3 className="text-lg font-semibold text-gray-900 dark:text-white flex items-center gap-2" itemProp="name">
                            {tool.name}
                            <a 
                              href={tool.link1}
                              target="_blank"
                              rel="noopener noreferrer"
                              className="text-indigo-600 hover:text-indigo-700 dark:text-indigo-400 dark:hover:text-indigo-300 transition-colors"
                              aria-label={`Visit ${tool.name} website`}
                            >
                              <ExternalLink size={16} aria-hidden="true" />
                            </a>
                          </h3>
                          <p className="mt-2 text-gray-600 dark:text-gray-300 leading-relaxed" itemProp="description">{tool.description}</p>
                        </div>
                        <span className="inline-flex items-center px-3 py-1 rounded-full text-sm font-medium bg-indigo-100 dark:bg-indigo-900 text-indigo-800 dark:text-indigo-200 whitespace-nowrap" itemProp="offers" itemScope itemType="https://schema.org/Offer">
                          <span itemProp="price">{tool.fees}</span>
                        </span>
                      </div>
                    </article>
                  ))}
                </div>
              </section>
            ))}
          </div>
        </main>

        {/* Footer */}
        <footer className="bg-white/80 dark:bg-gray-800/80 backdrop-blur-sm border-t border-gray-200 dark:border-gray-700 mt-12" role="contentinfo">
          <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8 py-6">
            <p className="text-center text-gray-500 dark:text-gray-400">© 2024 Your AI Tools. All rights reserved.</p>
          </div>
        </footer>
      </div>
    </>
  );
}

export default App;